# ACL Types

PRIVATE = 'private'
PUBLIC_READ = 'public-read'
PUBLIC_READ_WRITE = 'public-read-write'
AUTHENTICATED_READ = 'authenticated-read'

ACCESS_CONTROL_TYPES = [PRIVATE, PUBLIC_READ, PUBLIC_READ_WRITE, AUTHENTICATED_READ]
