# Generated by Django 2.2 on 2019-04-08 10:55

from django.db import migrations, models
import django_fsm
import uuid


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='UploadedFile',
            fields=[
                ('id', models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                ('created', models.DateTimeField(auto_now_add=True, db_index=True)),
                ('modified', models.DateTimeField(auto_now=True)),
                ('file_key', models.CharField(blank=True, max_length=255)),
                ('filename', models.CharField(blank=True, max_length=255)),
                ('file_upload_state', django_fsm.FSMField(default='NEW', max_length=50)),
            ],
            options={
                'ordering': ['-created'],
            },
            bases=(django_fsm.ConcurrentTransitionMixin, models.Model),
        ),
    ]
